jamviz.plt package
==================

Submodules
----------

jamviz.plt.color\_list module
-----------------------------

.. automodule:: jamviz.plt.color_list
   :members:
   :undoc-members:
   :show-inheritance:

jamviz.plt.mstd module
----------------------

.. automodule:: jamviz.plt.mstd
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jamviz.plt
   :members:
   :undoc-members:
   :show-inheritance:
